@@ -19,7 +19,7 @@ DiscreteChoiceSearcher<hasWeight, modelType, distType>::DiscreteChoiceSearcher(
     Ti SizeG, const std::vector<std::vector<Ti>> &groupIndexMap,
     const std::vector<Ti> &groupSizes, Ti fixFirstG, const Matrix<Tv> &source,
     Ti numChoices, const std::vector<Matrix<Tv>> &costMatrixes,
-    unsigned int seed, Newton &newtonOptions)
+    unsigned int seed, Newton &newtonOptions, RocOptions &aucOptions)
     : Searcher::Searcher(searchOptions, searchItems, measures, checks, SizeG,
                          groupIndexMap, groupSizes, fixFirstG) {
 
@@ -33,6 +33,8 @@ DiscreteChoiceSearcher<hasWeight, modelType, distType>::DiscreteChoiceSearcher(
   Data =
       Dataset<Tv>(numObs, cols, true); // size + endogenous, intercept, weight
 
+  pAucOptions = &aucOptions;
+
   if (this->pChecks->Estimation) {
     DModel =
         DiscreteChoice<modelType, distType>(numObs, numExo, numChoices, false);
@@ -81,24 +83,26 @@ DiscreteChoiceSearcher<hasWeight, modelType, distType>::DiscreteChoiceSearcher(
 
   if (measures.mIndexOfCostMatrixIn != -1 || measures.mIndexOfAucIn != -1) {
     if (hasWeight && measures.WeightedEval)
-      CostIn = std::unique_ptr<CostMatrixBase>(
-          new CostMatrix<true>((Ti)costMatrixes.size()));
+      CostIn = std::unique_ptr<FrequencyCostBase>(
+          new FrequencyCost<true>((Ti)costMatrixes.size()));
     else
-      CostIn = std::unique_ptr<CostMatrixBase>(
-          new CostMatrix<false>((Ti)costMatrixes.size()));
+      CostIn = std::unique_ptr<FrequencyCostBase>(
+          new FrequencyCost<false>((Ti)costMatrixes.size()));
     Probs = Matrix<Tv>(numObs, numChoices);
     this->WorkSize +=
         std::max(numObs + numChoices - 2, CostIn.get()->StorageSize) +
         numObs * numChoices;
   }
   if (measures.mIndexOfAucIn != -1) {
+
+    if (modelType == DiscreteChoiceModelType::kBinary) {
+      std::logic_error("not implemented discrete choice model type");
+    }
+
     if (hasWeight && measures.WeightedEval)
-      AucIn = std::unique_ptr<AucBase>(
-          new AUC<true, modelType == DiscreteChoiceModelType::kBinary>(numObs));
+      AucIn = std::unique_ptr<RocBase>(new ROC<true, false>(numObs));
     else
-      AucIn = std::unique_ptr<AucBase>(
-          new AUC<false, modelType == DiscreteChoiceModelType::kBinary>(
-              numObs));
+      AucIn = std::unique_ptr<RocBase>(new ROC<false, false>(numObs));
   }
 }
 
@@ -188,7 +192,7 @@ DiscreteChoiceSearcher<hasWeight, modelType, distType>::EstimateOne(Tv *work,
 
     Model.Calculate(Data.Result, pCostMatrixes, &work[s],
                     &work[s + Model.StorageSize], &workI[this->SizeG + 1],
-                    this->pOptions->RequestCancel,
+                    this->pOptions->RequestCancel, *pAucOptions,
                     this->pMeasures->SimFixSize - this->pChecks->MinOutSim,
                     nullptr, INT32_MAX);
     s += Model.StorageSize;
@@ -230,7 +234,7 @@ DiscreteChoiceSearcher<hasWeight, modelType, distType>::EstimateOne(Tv *work,
         AucIn.get()->Calculate(
             Y, Probs,
             hasWeight ? (measures.WeightedEval ? &W : nullptr) : nullptr,
-            &AucWeightsMc);
+            *pAucOptions);
         Weights.Set0(measures.mIndexOfAucIn, 0, AucIn.get()->Result);
       }
     }
@@ -240,7 +244,7 @@ DiscreteChoiceSearcher<hasWeight, modelType, distType>::EstimateOne(Tv *work,
     Ti cc = (Ti)measures.MeasuresIn.size();
     if (measures.mIndexOfCostMatrixOut != -1)
       Weights.Set0(cc + measures.mIndexOfCostMatrixOut, 0,
-                   GoodnessOfFit::ToWeight(GoodnessOfFitType::kCostMatrix,
+                   GoodnessOfFit::ToWeight(GoodnessOfFitType::kFrequencyCost,
                                            Model.CostRatios.Mean()));
     if (measures.mIndexOfAucOut != -1)
       Weights.Set0(cc + measures.mIndexOfAucOut, 0,
@@ -309,31 +313,35 @@ DiscreteChoiceModelsetBase *DiscreteChoiceModelsetBase::GetFromTypes(
     SearchModelChecks &checks, const std::vector<Ti> &sizes,
     const Matrix<Tv> &source, std::vector<Matrix<Tv>> &costMatrixes,
     std::vector<std::vector<Ti>> &groupIndexMaps, bool addLogit, bool addProbit,
-    Newton &newtonOptions) {
+    Newton &newtonOptions, RocOptions &aucOptions) {
   DiscreteChoiceModelsetBase *modelset;
   if (isBinary) {
     if (hasWeight) {
       modelset =
           new DiscreteChoiceModelset<true, DiscreteChoiceModelType::kBinary>(
               searchOptions, searchItems, measures, checks, sizes, source,
-              costMatrixes, groupIndexMaps, newtonOptions, addLogit, addProbit);
+              costMatrixes, groupIndexMaps, newtonOptions, aucOptions, addLogit,
+              addProbit);
     } else {
       modelset =
           new DiscreteChoiceModelset<false, DiscreteChoiceModelType::kBinary>(
               searchOptions, searchItems, measures, checks, sizes, source,
-              costMatrixes, groupIndexMaps, newtonOptions, addLogit, addProbit);
+              costMatrixes, groupIndexMaps, newtonOptions, aucOptions, addLogit,
+              addProbit);
     }
   } else {
     if (hasWeight) {
       modelset =
           new DiscreteChoiceModelset<true, DiscreteChoiceModelType::kOrdered>(
               searchOptions, searchItems, measures, checks, sizes, source,
-              costMatrixes, groupIndexMaps, newtonOptions, addLogit, addProbit);
+              costMatrixes, groupIndexMaps, newtonOptions, aucOptions, addLogit,
+              addProbit);
     } else {
       modelset =
           new DiscreteChoiceModelset<false, DiscreteChoiceModelType::kOrdered>(
               searchOptions, searchItems, measures, checks, sizes, source,
-              costMatrixes, groupIndexMaps, newtonOptions, addLogit, addProbit);
+              costMatrixes, groupIndexMaps, newtonOptions, aucOptions, addLogit,
+              addProbit);
     }
   }
   return modelset;
@@ -352,7 +360,7 @@ DiscreteChoiceModelset<hasWeight, modelType>::DiscreteChoiceModelset(
     const std::vector<Ti> &sizes, const Matrix<Tv> &source,
     std::vector<Matrix<Tv>> &costMatrixes,
     std::vector<std::vector<Ti>> &groupIndexMaps, Newton &newtonOptions,
-    bool addLogit, bool addProbit) {
+    RocOptions &aucOptions, bool addLogit, bool addProbit) {
 
   // find numChoices
   Ti r = 0;
@@ -421,17 +429,17 @@ DiscreteChoiceModelset<hasWeight, modelType>::DiscreteChoiceModelset(
   if (measures.mIndexOfCostMatrixIn == -1 &&
       measures.mIndexOfCostMatrixOut == -1) {
     if (costMatrixes.size() > 0)
-      throw std::logic_error(
-          "There is no cost matrix measure and yet cost matrix list is not "
-          "empty!");
+      throw std::logic_error("There is no frequency cost measure and yet "
+                             "frequency cost matrix list is not "
+                             "empty!");
   } else if (measures.mIndexOfCostMatrixIn != -1 ||
              measures.mIndexOfCostMatrixOut != -1) {
     if (costMatrixes.size() == 0)
-      throw std::logic_error(
-          "Cost matrix measures are given, however cost matrix list is "
-          "empty!");
+      throw std::logic_error("Frequency cost measures are given, "
+                             "however frequency cost matrix list is "
+                             "empty!");
     for (auto const &table : costMatrixes) {
-      CostMatrix<hasWeight>::Check(table, this->mNumChoices);
+      FrequencyCost<hasWeight>::Check(table, this->mNumChoices);
     }
   }
 
@@ -453,7 +461,7 @@ DiscreteChoiceModelset<hasWeight, modelType>::DiscreteChoiceModelset(
                                      DiscreteChoiceDistType::kLogit>(
               searchOptions, searchItems, measures, checks, s, groupIndexMaps,
               this->GroupSizes, 0, source, this->mNumChoices, costMatrixes,
-              seed, newtonOptions));
+              seed, newtonOptions, aucOptions));
     }
     if (addProbit) {
       this->Searchers.push_back(
@@ -461,7 +469,7 @@ DiscreteChoiceModelset<hasWeight, modelType>::DiscreteChoiceModelset(
                                      DiscreteChoiceDistType::kProbit>(
               searchOptions, searchItems, measures, checks, s, groupIndexMaps,
               this->GroupSizes, 0, source, this->mNumChoices, costMatrixes,
-              seed, newtonOptions));
+              seed, newtonOptions, aucOptions));
     }
   }
 
