@@ -3,7 +3,7 @@
 
 using namespace ldt;
 
-template <typename Tw> Variable<Tw>::Variable(){};
+template <typename Tw> Variable<Tw>::Variable() {}
 
 template <typename Tw>
 std::unique_ptr<Frequency> Variable<Tw>::GetEndFrequency() const {
